@@ -1,5 +1,5 @@
 package Util::Medley::List;
-$Util::Medley::List::VERSION = '0.010';
+$Util::Medley::List::VERSION = '0.011';
 #########################################################################################
 
 use Modern::Perl;
@@ -8,6 +8,7 @@ use namespace::autoclean;
 use Kavorka '-all';
 use Data::Printer alias => 'pdump';
 use List::Util;
+use Sort::Naturally;
 
 =head1 NAME
 
@@ -15,7 +16,7 @@ Util::Medley::List - utility methods for working with lists
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =cut
 
@@ -133,6 +134,44 @@ multi method max (ArrayRef :$list!) {
 	return $self->max(@$list);	
 }
 
+
+=head1 nsort 
+
+Sort an array naturally (case in-sensitive).  Just a passthrough to
+Sort::Naturally::nsort.
+
+=over
+
+=item usage:
+
+ @sorted = $util->nsort(@list);
+ 
+ @sorted = $util->nsort(list => \@list);
+
+=item args:
+
+=over
+
+=item list [Array|ArrayRef]
+
+The list to act on.
+
+=back
+
+=back
+ 
+=cut
+
+multi method nsort (ArrayRef :$list!) {
+
+	return $self->nsort(@$list);
+}
+
+multi method nsort (@list) {
+
+	return Sort::Naturally::nsort(@list);
+}
+
 =head2 undefsToStrings
 
 =over
