@@ -1,5 +1,5 @@
 package Util::Medley::XML;
-$Util::Medley::XML::VERSION = '0.010';
+$Util::Medley::XML::VERSION = '0.011';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -16,7 +16,7 @@ Util::Medley::XML - utility XML methods
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =cut
 
@@ -49,7 +49,7 @@ Beautifies an XML file.  Requires the xmllint command.
 
  $util->xmlBeautifyFile($path);
 
- $util->XmlBeautifyFile(path => $path);
+ $util->xmlBeautifyFile(path => $path);
  
 =item args:
 
